summaryrefslogtreecommitdiffstats
path: root/libtdepim/kaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/kaccount.h')
-rw-r--r--libtdepim/kaccount.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libtdepim/kaccount.h b/libtdepim/kaccount.h
index d0a1b7f2..559a3c03 100644
--- a/libtdepim/kaccount.h
+++ b/libtdepim/kaccount.h
@@ -35,7 +35,7 @@
#include <tqstring.h>
#include <tdepimmacros.h>
-class KConfig;
+class TDEConfig;
class KDE_EXPORT KAccount
{
@@ -73,15 +73,15 @@ class KDE_EXPORT KAccount
/**
* Save the settings
* If the group is empty it must be preset in the KConfig
*/
- void writeConfig( KConfig &config, const TQString &group = TQString() );
+ void writeConfig( TDEConfig &config, const TQString &group = TQString() );
/**
* Read the settings
* If the group is empty it must be preset in the KConfig
*/
- void readConfig( KConfig &config, const TQString &group = TQString() );
+ void readConfig( TDEConfig &config, const TQString &group = TQString() );
protected:
uint mId;
@@ -73,15 +73,15 @@ class KDE_EXPORT KAccount
/**
* Save the settings
- * If the group is empty it must be preset in the KConfig
+ * If the group is empty it must be preset in the TDEConfig
*/
@@ -73,15 +73,15 @@ class KDE_EXPORT KAccount
/**
* Read the settings
- * If the group is empty it must be preset in the KConfig
+ * If the group is empty it must be preset in the TDEConfig
*/